@@ -32,6 +32,13 @@
 #define MSG_WAITALL 0
 #endif
 
+/*
+ * Legacy stub, please ignore.
+ */
+int opennet_init(void) {
+	return(0);
+}
+
 static int parse_url(char *url, char **scheme, char **user, char **pass, char **host, int *port, char **path) {
 	char *tmptr, *schemeptr, *pathptr, *userptr, *passptr, *hostptr, *portptr;
 
@@ -269,6 +276,7 @@ int feof_net(NETFILE *stream) {
 
 size_t fread_net(void *ptr, size_t size, size_t nmemb, NETFILE *stream) {
 	ssize_t recv_ret;
+	size_t retval;
 	int bytes_to_copy;
 
 	if (stream->fd >= 0) {
@@ -312,7 +320,9 @@ size_t fread_net(void *ptr, size_t size, size_t nmemb, NETFILE *stream) {
 		stream->bufsize = stream->bufsize_s;
 	}
 
-	return(nmemb);
+	retval = bytes_to_copy / size;
+
+	return(retval);
 }
 
 char *fgets_net(char *s, int size, NETFILE *stream) {
